@@ -1,5 +1,5 @@
 /*
- * $Id: wmbatppc.c 28 2004-02-22 12:43:48Z julien $
+ * $Id: wmbatppc.c 32 2004-10-13 17:43:38Z julien $
  *
  * wmbatppc, originally written by Lou <titelou@free.fr>
  *
@@ -29,6 +29,9 @@
  *    + you can now specify the path to the UNIX domain socket with the -u switch.
  *    + some code cleanup at last, eliminating most of the global variables.
  *    + changed the way OSD display works.
+ * * 20041013 v2.5 Julien BLACHE <jb@jblache.org>
+ *    + fixed compilation without ENABLE_XOSD
+ *    + added runtime switch to disable OSD
  */
 
 #include <stdlib.h>
@@ -170,32 +173,35 @@ void initWMGUIelements (void)
   gui.jukeBoxSize[1].y = 0;
 }
 
-void initXPMelements (void)
+void initXPMelements (int xoff, int yoff)
 {
+  xpm.offset.x = xoff;
+  xpm.offset.y = yoff;
+
   xpm.timeleftIndSize.x = 36 ;
   xpm.timeleftIndSize.y = 13 ;
   xpm.timeleftIndImg.x = 15;
-  xpm.timeleftIndImg.y = 29 + xpm.YOFFSET;
+  xpm.timeleftIndImg.y = 29 + xpm.offset.y;
   xpm.voltIndSize.x = 34;
   xpm.voltIndSize.y = 10;
   xpm.voltIndImg.x = 2;
-  xpm.voltIndImg.y = 84 + xpm.YOFFSET; 
+  xpm.voltIndImg.y = 84 + xpm.offset.y; 
   xpm.battImg[LEFT_BATTERY*4+HIGH_BATT].x = 146;
-  xpm.battImg[LEFT_BATTERY*4+HIGH_BATT].y = 6 + xpm.YOFFSET;
+  xpm.battImg[LEFT_BATTERY*4+HIGH_BATT].y = 6 + xpm.offset.y;
   xpm.battImg[LEFT_BATTERY*4+LOW_BATT].x = 173;
-  xpm.battImg[LEFT_BATTERY*4+LOW_BATT].y = 6 + xpm.YOFFSET;
+  xpm.battImg[LEFT_BATTERY*4+LOW_BATT].y = 6 + xpm.offset.y;
   xpm.battImg[LEFT_BATTERY*4+MED_BATT].x = 200;
-  xpm.battImg[LEFT_BATTERY*4+MED_BATT].y = 6 + xpm.YOFFSET;
+  xpm.battImg[LEFT_BATTERY*4+MED_BATT].y = 6 + xpm.offset.y;
   xpm.battImg[LEFT_BATTERY*4+NO_BATT].x = 108;
-  xpm.battImg[LEFT_BATTERY*4+NO_BATT].y = 85 + xpm.YOFFSET;
+  xpm.battImg[LEFT_BATTERY*4+NO_BATT].y = 85 + xpm.offset.y;
   xpm.battImg[RIGHT_BATTERY*4+HIGH_BATT].x = 146;
-  xpm.battImg[RIGHT_BATTERY*4+HIGH_BATT].y = 21 + xpm.YOFFSET;
+  xpm.battImg[RIGHT_BATTERY*4+HIGH_BATT].y = 21 + xpm.offset.y;
   xpm.battImg[RIGHT_BATTERY*4+LOW_BATT].x = 173;
-  xpm.battImg[RIGHT_BATTERY*4+LOW_BATT].y = 21 + xpm.YOFFSET;
+  xpm.battImg[RIGHT_BATTERY*4+LOW_BATT].y = 21 + xpm.offset.y;
   xpm.battImg[RIGHT_BATTERY*4+MED_BATT].x = 200;
-  xpm.battImg[RIGHT_BATTERY*4+MED_BATT].y = 21 + xpm.YOFFSET;
+  xpm.battImg[RIGHT_BATTERY*4+MED_BATT].y = 21 + xpm.offset.y;
   xpm.battImg[RIGHT_BATTERY*4+NO_BATT].x = 135;
-  xpm.battImg[RIGHT_BATTERY*4+NO_BATT].y = 85 + xpm.YOFFSET;
+  xpm.battImg[RIGHT_BATTERY*4+NO_BATT].y = 85 + xpm.offset.y;
   xpm.battSize.x = 25;
   xpm.battSize.y = 13;
   xpm.plugSize.x = 12;
@@ -203,48 +209,47 @@ void initXPMelements (void)
   xpm.chargSize.x = 12;
   xpm.chargSize.y = 16;
   xpm.plugImg[0].x = 158;
-  xpm.plugImg[0].y = 53 + xpm.YOFFSET;
+  xpm.plugImg[0].y = 53 + xpm.offset.y;
   xpm.plugImg[1].x = 158;
-  xpm.plugImg[1].y = 36 + xpm.YOFFSET;
+  xpm.plugImg[1].y = 36 + xpm.offset.y;
   xpm.chargImg[0].x = 134;
-  xpm.chargImg[0].y = 53 + xpm.YOFFSET;
+  xpm.chargImg[0].y = 53 + xpm.offset.y;
   xpm.chargImg[1].x = 134;
-  xpm.chargImg[1].y = 36 + xpm.YOFFSET;
+  xpm.chargImg[1].y = 36 + xpm.offset.y;
   xpm.jukeBoxImg[0].x = 173; 
-  xpm.jukeBoxImg[0].y = 68 + xpm.YOFFSET;
+  xpm.jukeBoxImg[0].y = 68 + xpm.offset.y;
   xpm.jukeBoxImg[1].x = 5;
-  xpm.jukeBoxImg[1].y = 101 + xpm.YOFFSET;
+  xpm.jukeBoxImg[1].y = 101 + xpm.offset.y;
   xpm.jukeBoxImg[2].x = 126;
-  xpm.jukeBoxImg[2].y = 135 + xpm.YOFFSET;
+  xpm.jukeBoxImg[2].y = 135 + xpm.offset.y;
   xpm.jukeBoxImg[3].x = 4;
-  xpm.jukeBoxImg[3].y = 168 + xpm.YOFFSET;
+  xpm.jukeBoxImg[3].y = 168 + xpm.offset.y;
   xpm.jukeBoxImg[4].x = 127;
-  xpm.jukeBoxImg[4].y = 168 + xpm.YOFFSET;
+  xpm.jukeBoxImg[4].y = 168 + xpm.offset.y;
   xpm.jukeBoxImg[5].x = 65;
-  xpm.jukeBoxImg[5].y = 168 + xpm.YOFFSET;
+  xpm.jukeBoxImg[5].y = 168 + xpm.offset.y;
   xpm.jukeBoxImg[6].x = 127;
-  xpm.jukeBoxImg[6].y = 101 + xpm.YOFFSET;
+  xpm.jukeBoxImg[6].y = 101 + xpm.offset.y;
   xpm.jukeBoxImg[7].x = 4;
-  xpm.jukeBoxImg[7].y = 135 + xpm.YOFFSET;
+  xpm.jukeBoxImg[7].y = 135 + xpm.offset.y;
   xpm.jukeBoxImg[8].x = 65;
-  xpm.jukeBoxImg[8].y = 135 + xpm.YOFFSET;
+  xpm.jukeBoxImg[8].y = 135 + xpm.offset.y;
   xpm.jukeBoxImg[9].x = 66;
-  xpm.jukeBoxImg[9].y = 101 + xpm.YOFFSET;
+  xpm.jukeBoxImg[9].y = 101 + xpm.offset.y;
   xpm.jukeBoxImg[10].x = 173;
-  xpm.jukeBoxImg[10].y = 36 + xpm.YOFFSET;
+  xpm.jukeBoxImg[10].y = 36 + xpm.offset.y;
 }
 
 void initGUIelements (wm_info *wm)
 {
   if (wm->type == WMAKER)
     {
-      initXPMelements();
+      initXPMelements(0, 0);
       initWMGUIelements();
     }
   else
     {
-      xpm.YOFFSET = 30;
-      initXPMelements();
+      initXPMelements(0, 30);
       initXIMGUIelements();
     }
 }
@@ -662,7 +667,7 @@ void DisplayBat(void)
 	  millivolts =  sys_pmu.b[par].voltage % 1000;
 	  BlitNum(volts, gui.voltage[V].x, gui.voltage[V].y, SMALL, 1);
 	  BlitNum(millivolts, gui.voltage[MV].x, gui.voltage[MV].y, SMALL, 0);
-	  copyXPMArea(74, (69 + xpm.YOFFSET), 2, 3, gui.symbols[COMMA].x, gui.symbols[COMMA].y);
+	  copyXPMArea(74, (69 + xpm.offset.y), 2, 3, gui.symbols[COMMA].x, gui.symbols[COMMA].y);
 	}
     }
 
@@ -825,7 +830,10 @@ int main(int argc, char *argv[])
   int i;
   wm_info wm;
   char *progname;
-  
+#ifdef ENABLE_XOSD
+  int osd = 1; /* OSD activated by default */
+#endif /* ENABLE_XOSD */
+
   /* init */
   sys_pmu.pmud_domain = PF_INET;
   strcpy(sys_pmu.socket_path, PMUD_SOCKET_PATH);
@@ -833,8 +841,8 @@ int main(int argc, char *argv[])
   sys_pmu.update_rate = UPDATE_RATE;
   sys_pmu.read_pmu = read_pmu_proc;
 
-  xpm.XOFFSET = 0;
-  xpm.YOFFSET = 0;
+  xpm.offset.x = 0;
+  xpm.offset.y = 0;
 
   signal(SIGCHLD, sig_chld);
 
@@ -898,6 +906,11 @@ int main(int argc, char *argv[])
       case 'x':
 	wm.type = XIMIAN;
 	break;
+#ifdef ENABLE_XOSD
+      case 'o':
+	osd = 0;
+	break;
+#endif /* ENABLE_XOSD */
       default:
 	usage();
 	exit(0);
@@ -945,9 +958,12 @@ int main(int argc, char *argv[])
        * 1 line for the left battery
        * 1 line for the right battery
        */
-      gui.osd = xosd_create(3);
+      if (osd)
+	{
+	  gui.osd = xosd_create(3);
+	}
       
-      if (gui.osd == NULL)
+      if ((osd) && (gui.osd == NULL))
 	{
 	  fprintf(stderr, "%s: OSD disabled after error (%s)\n", progname, xosd_error);
 	}
@@ -1058,7 +1074,9 @@ void wmbatppc_routine (int argc, char **argv, wm_info *wm)
 		XCloseDisplay(display);
 		exit(0);
 	      case ButtonPress:
+#ifdef ENABLE_XOSD
 		DisplayOSD();
+#endif /* ENABLE_XOSD */
 		break;
 	    }
 	}
@@ -1084,7 +1102,7 @@ void BlitString (char *name, int x, int y, int is_big)
       if (c >= 'A' && c <= 'Z') /* its a letter */
 	{
 	  c -= 'A';
-	  copyXPMArea(c * 6, 74+xpm.YOFFSET, 6, 8, k, y);
+	  copyXPMArea(c * 6, 74+xpm.offset.y, 6, 8, k, y);
 	  k += 6;
 	} 
       else
@@ -1094,18 +1112,18 @@ void BlitString (char *name, int x, int y, int is_big)
 	      c -= '0';
 	      if (is_big == BIG)
 		{
-		  copyXPMArea(68 + c * 7 , 22+xpm.YOFFSET, 7, 10, k, y);
+		  copyXPMArea(68 + c * 7 , 22+xpm.offset.y, 7, 10, k, y);
 		  k += 7 ;
 		}
 	      else
 		{
-		  copyXPMArea(c * 6, 64+xpm.YOFFSET, 6, 8, k, y);
+		  copyXPMArea(c * 6, 64+xpm.offset.y, 6, 8, k, y);
 		  k += 6;
 		}
 	    }
 	  else
 	    {
-	      copyXPMArea(1, 84+xpm.YOFFSET, 6, 8, k, y);
+	      copyXPMArea(1, 84+xpm.offset.y, 6, 8, k, y);
 	      k += 6;
 	    }
 	}
@@ -1125,7 +1143,7 @@ void BlitNum (int num, int x, int y, int is_big, int two_digits)
       if (two_digits == 2)
 	{
 	  temp = num - 100;
-	  copyXPMArea(10, 64+xpm.YOFFSET, 2, 8, x+4, y); /* print the hundreds unit */
+	  copyXPMArea(10, 64+xpm.offset.y, 2, 8, x+4, y); /* print the hundreds unit */
 	  newx = x + 6;
 	  sprintf(buf, "%02i", temp);
 	}
@@ -1150,6 +1168,9 @@ void usage (void)
   fprintf(stderr, "    -geometry <X11 geometry string>\n");
   fprintf(stderr, "    -r	      update rate in milliseconds (default:100)\n");
   fprintf(stderr, "    -w             WindowMaker/AfterStep GUI\n");
+#ifdef ENABLE_XOSD
+  fprintf(stderr, "    -o             disable On-Screen Display\n");
+#endif /* ENABLE_XOSD */
   fprintf(stderr, "    -x             swallowed application GUI (for GNOME Panel)\n");
   fprintf(stderr, "    -t             use pmud on TCP port 879\n");
   fprintf(stderr, "    -u [PATH]      use pmud via UNIX domain socket\n");
