@@ -1,7 +1,7 @@
 /*
  * Revision 0.2  24 Nov 2000 Lou
  *
- * $Id: wmbatppc.h 28 2004-02-22 12:43:48Z julien $
+ * $Id: wmbatppc.h 32 2004-10-13 17:43:38Z julien $
  */
 
 #ifndef __WMBATPPC_H__
@@ -19,7 +19,7 @@
 # define UNIX_PATH_MAX 108
 #endif
 
-#define WMBATPPC_VERSION       "2.4"
+#define WMBATPPC_VERSION       "2.5"
 
 #define LEFT_BATTERY           0
 #define RIGHT_BATTERY          1
@@ -136,8 +136,7 @@ typedef struct
 
 typedef struct
 {
-  int XOFFSET;
-  int YOFFSET;
+  coords offset;
   coords jukeBoxImg[12];
   coords plugImg[2];
   coords chargImg[2];
